from setuptools import setup

setup(name = 'Eben_distributions',
    version ='0.1',
    description = 'Gaussian distributions',
    package = ['distributions'],
    author = 'Ebenezer Olubayode',
    author_email = 'Olubayodeeben@yahoo.com',
    zip_safe = False) 